##  Key Sections and Metrics
The following table lists the key sections and metrics available in a Shared 360 view.
Section | Description | Related Information
---|---|---
Summary | Shows the current health score, the NPS score, the number of unresolved support tickets, as well as the name of your Customer Success Manager and Account Executive. |
EAM Attributes | A snapshot of the SAP LeanIX product being used, including the edition, the total number of applications and fact sheets, standard and custom integrations, and other related details. |
Success Plans | A list of success plans built in collaboration with the SAP LeanIX Customer Success team. |
Active Permissions | Overview of daily and monthly active user permissions in each live workspace. |
Login Statistics | The number of total and unique logins within specific time frames (daily, weekly, and monthly). As an example, if a user logs into SAP LeanIX 50 times within a certain period, that user's total login count would be 50. However, since it's the same user each time, the count of unique logins would be considered as one. |
Login Statistics per Role | Monthly login counts by role type: Admin, Contact, Member, Viewer, and Custom. |
  * [User Roles and Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD "Adjust role-based permissions and define custom roles.")
  * [Adding Non-SAP-LeanIX Users as Subscribers](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a16427a441014be448690c54e7cf0__adding_non-sap-leanix_users_as_subscribers)


New vs Existing Logins | The number of monthly logins of new and existing users in all or live workspaces. If a user's first login falls within the current month, they are categorized as New. Conversely, if their first login occurred in any of the previous months, they are labeled as Existing. |
User Segments | Reports with information about the users' job titles and their jobs-to-be-done provided by them during the sign-in process. Use these reports to understand the profiles of new users and the value they aim to derive from using SAP LeanIX. | [User Segments](https://help.sap.com/docs/leanix/ea/general-settings?locale=en-US&state=PRODUCTION&version=CLOUD#loio275959347a44101489cfee4fe45f7c0f__user_segments)
Workspace Elements | Daily snapshots of the total count of applications and fact sheets in live, demo, and sandbox workspaces. Note that, archived application fact sheets, as well as those created from transformation items that haven’t been executed yet, do not count toward the pricing quota. |
  * [Application](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page guides you on modeling applications, covering subtypes, best practices, versioning, hierarchies, and use cases. Avoid common antipatterns and gain valuable insights.")
  * [Inventory](https://help.sap.com/docs/leanix/ea/inventory?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory is your centralized repository for managing and documenting enterprise architecture objects. You create, edit, and organize fact sheets to maintain an accurate depiction of your IT landscape. It is the go-to place for anyone seeking information from the fact sheets.")
  * [Archiving and Recovering Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Learn to archive fact sheets individually or in bulk and effortlessly view or recover archived fact sheets in SAP LeanIX.")
  * [Transformation Templates](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.")


Fact Sheet Statistics | Monthly snapshots of created, viewed, updated, and archived fact sheets in live, demo, and sandbox workspaces. The frequency of updates in fact sheets often serves as an indicator of data quality. Specifically, frequent updates usually signify high data quality, whereas infrequent updates may imply lower data quality. |  [Inventory](https://help.sap.com/docs/leanix/ea/inventory?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory is your centralized repository for managing and documenting enterprise architecture objects. You create, edit, and organize fact sheets to maintain an accurate depiction of your IT landscape. It is the go-to place for anyone seeking information from the fact sheets.")
Reporting Statistics | Monthly and daily snapshots of report views in live, demo, and sandbox workspaces broken down by the report type. These snapshots offer insights into the most frequently viewed or used reports, highlighting the kind of information that your team members are looking for. |  [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD)
Zendesk Support Tickets | Support tickets submitted to SAP LeanIX Support through Zendesk. |  [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support")
Workspace Session Tracking | Report providing information about user actions performed in various sections of a workspace, such as Dashboards, Inventory, Reports, Diagrams, sections in the admin area, and more. By using the report, you can understand the usage and adoption of specific areas or features within the workspace, for example, the number of interactions with dashboards in the past month. For details on report metrics, see [Workspace Session Tracking](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption?locale=en-US&state=PRODUCTION&version=CLOUD#loio275b5fe67a441014b069f1877aeece85__workspace_session_tracking). |
Portals Usage | Tracking of visits and unique visitors to portal pages. | [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.")
Workspace Views Usage | Tracking of unique users of workspace views. | [Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views?locale=en-US&state=PRODUCTION&version=CLOUD "Use workspace views configured by admins to limit the scope of displayed information and focus on your current tasks.")
EA Maturity Assessment | Overview of all past responses related to the [EA Maturity Assessment![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fea-maturity-assessment "https://www.leanix.net/en/ea-maturity-assessment"), including a link to the report with recommendations to improve your enterprise architecture (EA) practice. |
Community Activity | Reports providing insights into user engagement within the SAP LeanIX Community: the number of monthly active users, the number of posts, the most popular topics, and the user growth trend. |  [SAP LeanIX Community![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fcommunity.leanix.net%2F "https://community.leanix.net/")
Product Ideas | A list of product ideas submitted through the SAP LeanIX Product Roadmap and their statuses: - Pending Review: Initial status for ideas awaiting review and action from our product team. - Accepted: Indicates that the request has passed an initial review and will move forward in the process. |  [SAP LeanIX Product Roadmap![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2F "https://roadmap.leanix.net/")


